<?php
/**
 * Suits functions and definitions.
 *
 * @package Suits
 * @since Suits 1.0
 */

/**
 * Sets up the content width value based on the theme's design.
 * @see suits_content_width() for template-specific adjustments.
 */
if ( ! isset( $content_width ) )
	$content_width = 620;

/**
 * Adds support for a custom header image.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Sets up theme defaults and registers the various WordPress features that
 * Suits supports.
 *
 * @uses add_editor_style() To add Visual Editor stylesheets.
 * @uses add_theme_support() To add support for automatic feed links
 * and post thumbnails.
 * @uses register_nav_menu() To add support for a navigation menu.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since Suits 1.0
 *
 * @return void
 */
function suits_setup() {
	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( suits_fonts_url() ) );

	// Enables plugins and themes to manage the document title tag.
	add_theme_support( 'title-tag' );

	// Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	// Switches default core markup for search form, comment form, and comments
	// to output valid HTML5.
	add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list' ) );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Navigation Menu', 'suits' ) );

	/*
	 * This theme supports custom background color and image, and here
	 * we also set up the default background color.
	 */
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff',
	) );

	/*
	 * This theme uses a custom image size for featured images, displayed on
	 * "standard" posts and pages.
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 620, 9999 );

	// This theme uses its own gallery styles.
	add_filter( 'use_default_gallery_style', '__return_false' );
}
add_action( 'after_setup_theme', 'suits_setup' );

/**
 * Returns the Google font stylesheet URL, if available.
 *
 * @since Suits 1.0
 *
 * @return string Font stylesheet or empty string if disabled.
 */
function suits_fonts_url() {
	$fonts_url = '';

	/* Translators: If there are characters in your language that are not
	 * supported by Lato, translate this to 'off'. Do not translate into your
	 * own language.
	 */
	$lato = _x( 'on', 'Lato font: on or off', 'suits' );

	if ( 'off' !== $lato ) {
		$font_families = array();

		if ( 'off' !== $lato )
			$font_families[] = 'Lato:300,400';

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);
		$fonts_url = add_query_arg( $query_args, "//fonts.googleapis.com/css" );
	}

	return $fonts_url;
}

/**
 * Enqueues scripts and styles for front end.
 *
 * @since Suits 1.0
 *
 * @return void
 */
function suits_scripts_styles() {
	// Adds JavaScript to pages with the comment form to support sites with
	// threaded comments (when in use).
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	// Loads JavaScript file with functionality specific to Suits.
	wp_enqueue_script( 'suits-script', get_template_directory_uri() . '/js/functions.js', array( 'jquery' ), '2013-10-20', true );

	// Add Lato font, used in the main stylesheet.
	wp_enqueue_style( 'suits-fonts', suits_fonts_url(), array(), null );

	// Loads our main stylesheet.
	wp_enqueue_style( 'suits-style', get_stylesheet_uri(), array(), '2013-10-20' );
}
add_action( 'wp_enqueue_scripts', 'suits_scripts_styles' );

/**
 * Registers widget areas.
 *
 * @since Suits 1.0
 *
 * @return void
 */
function suits_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Main Sidebar', 'suits' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Appears on posts and pages in the sidebar.', 'suits' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer One', 'suits' ),
		'id'            => 'footer-1',
		'description'   => __( 'Appears in the footer section of the site.', 'suits' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Two', 'suits' ),
		'id'            => 'footer-2',
		'description'   => __( 'Appears in the footer section of the site.', 'suits' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Three', 'suits' ),
		'id'            => 'footer-3',
		'description'   => __( 'Appears in the footer section of the site.', 'suits' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'suits_widgets_init' );

if ( ! function_exists( 'suits_paging_nav' ) ) :
/**
 * Displays navigation to next/previous set of posts when applicable.
 *
 * @since Suits 1.0
 *
 * @return void
 */
function suits_paging_nav() {
	global $wp_query;

	// Don't print empty markup if there's only one page.
	if ( $wp_query->max_num_pages < 2 )
		return;
	?>
	<nav class="navigation paging-navigation" role="navigation">
		<div class="nav-links">

			<?php if ( get_next_posts_link() ) : ?>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older', 'suits' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer <span class="meta-nav">&rarr;</span>', 'suits' ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'suits_post_nav' ) ) :
/**
 * Displays navigation to next/previous post when applicable.
*
* @since Suits 1.0
*
* @return void
*/
function suits_post_nav() {
	global $post;

	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous )
		return;
	?>
	<nav class="navigation post-navigation" role="navigation">
		<div class="nav-links">

			<?php previous_post_link( '%link', _x( '<span class="meta-nav">&larr;</span> %title', 'Previous post link', 'suits' ) ); ?>
			<?php next_post_link( '%link', _x( '%title <span class="meta-nav">&rarr;</span>', 'Next post link', 'suits' ) ); ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'suits_entry_meta' ) ) :
/**
 * Prints HTML with meta information for current post: categories, tags, permalink, author, and date.
 *
 * Create your own suits_entry_meta() to override in a child theme.
 *
 * @since Suits 1.0
 */
function suits_entry_meta() {
	// Translators: used between list items, there is a space after the comma.
	$categories_list = get_the_category_list( __( ', ', 'suits' ) );

	// Translators: used between list items, there is a space after the comma.
	$tag_list = get_the_tag_list( '', __( ', ', 'suits' ) );

	$date = sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a>',
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() )
	);

	$author = sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'suits' ), get_the_author() ) ),
		get_the_author()
	);

	// Translators: 1 is category, 2 is tag, 3 is the date and 4 is the author's name.
	if ( $tag_list ) {
		$utility_text = __( 'Posted in %1$s and tagged %2$s<span class="on-date"> on %3$s</span><span class="by-author"> by %4$s</span>.', 'suits' );
	} elseif ( $categories_list ) {
		$utility_text = __( 'Posted in %1$s<span class="on-date"> on %3$s</span><span class="by-author"> by %4$s</span>.', 'suits' );
	} else {
		$utility_text = __( '<span class="on-date">Posted on %3$s</span><span class="by-author"> by %4$s</span>.', 'suits' );
	}

	printf(
		$utility_text,
		$categories_list,
		$tag_list,
		$date,
		$author
	);
}
endif;

if ( ! function_exists( 'suits_entry_date' ) ) :
/**
 * Prints HTML with date information for current post.
 *
 * Create your own suits_entry_date() to override in a child theme.
 *
 * @since Suits 1.0
 *
 * @param boolean $echo Whether to echo the date. Default true.
 * @return string The HTML-formatted post date.
 */
function suits_entry_date( $echo = true ) {
	$date = sprintf( '<span class="date"><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a></span>',
		esc_url( get_permalink() ),
		esc_attr( sprintf( __( 'Permalink to %s', 'suits' ), the_title_attribute( 'echo=0' ) ) ),
		esc_attr( get_the_date( 'c' ) ),
		esc_attr( get_the_date() )
	);

	if ( $echo )
		echo $date;

	return $date;
}
endif;

if ( ! function_exists( 'suits_the_attached_image' ) ) :
/**
 * Prints the attached image with a link to the next attached image.
 *
 * @since Suits 1.0
 *
 * @return void
 */
function suits_the_attached_image() {
	$post                = get_post();
	$attachment_size     = apply_filters( 'suits_attachment_size', array( 940, 940 ) );
	$next_attachment_url = wp_get_attachment_url();

	/**
	 * Grab the IDs of all the image attachments in a gallery so we can get the URL
	 * of the next adjacent image in a gallery, or the first image (if we're
	 * looking at the last image in a gallery), or, in a gallery of one, just the
	 * link to that image file.
	 */
	$attachment_ids = get_posts( array(
		'post_parent'    => $post->post_parent,
		'fields'         => 'ids',
		'numberposts'    => -1,
		'post_status'    => 'inherit',
		'post_type'      => 'attachment',
		'post_mime_type' => 'image',
		'order'          => 'ASC',
		'orderby'        => 'menu_order ID'
	) );

	// If there is more than 1 attachment in a gallery...
	if ( count( $attachment_ids ) > 1 ) {
		foreach ( $attachment_ids as $attachment_id ) {
			if ( $attachment_id == $post->ID ) {
				$next_id = current( $attachment_ids );
				break;
			}
		}

		// get the URL of the next image attachment...
		if ( $next_id )
			$next_attachment_url = get_attachment_link( $next_id );

		// or get the URL of the first image attachment.
		else
			$next_attachment_url = get_attachment_link( array_shift( $attachment_ids ) );
	}

	printf( '<a href="%1$s" title="%2$s" rel="attachment">%3$s</a>',
		esc_url( $next_attachment_url ),
		the_title_attribute( array( 'echo' => false ) ),
		wp_get_attachment_image( $post->ID, $attachment_size )
	);
}
endif;

/**
 * Extends the default WordPress body classes.
 *
 * Adds body classes to denote:
 * 1. Single or multiple authors.
 * 2. When avatars are disabled in discussion settings.
 * 3. Using a full-width layout.
 * 4. Active widgets in the sidebar to change the layout and spacing.
 *
 * @since Suits 1.0
 *
 * @param array $classes A list of existing body class values.
 * @return array The filtered body class list.
 */
function suits_body_class( $classes ) {
	if ( ! is_multi_author() )
		$classes[] = 'single-author';

	if ( ! get_option( 'show_avatars' ) )
		$classes[] = 'no-avatars';

	if ( ! is_active_sidebar( 'sidebar-1' ) || is_page_template( 'template-full-width.php' ) )
		$classes[] = 'full-width';

	$num_sidebars = 0;

	if ( is_active_sidebar( 'footer-1' ) )
		$num_sidebars++;

	if ( is_active_sidebar( 'footer-2' ) )
		$num_sidebars++;

	if ( is_active_sidebar( 'footer-3' ) )
		$num_sidebars++;

	switch( $num_sidebars ) :

		case 1:
			$classes[] = 'one-footer-sidebar';
			break;

		case 2:
			$classes[] = 'two-footer-sidebars';
			break;

		case 3:
			$classes[] = 'three-footer-sidebars';
			break;

		default:
			$classes[] = 'no-footer-sidebar';

	endswitch;

	return $classes;
}
add_filter( 'body_class', 'suits_body_class' );

/**
 * Adjusts content_width value for full-width and single image attachment
 * templates, and when there are no active widgets in the sidebar.
 *
 * @since Suits 1.0
 *
 * @return void
 */
function suits_content_width() {
	if ( is_page_template( 'template-full-width.php' ) || is_attachment() || ! is_active_sidebar( 'sidebar-1' ) ) {
		global $content_width;
		$content_width = 940;
	}
}
add_action( 'template_redirect', 'suits_content_width' );

/**
 * Add theme support for Infinite Scroll.
 * See: http://jetpack.me/support/infinite-scroll/
 *
 * @since Suits 1.0
 *
 * @return void
 */
function suits_jetpack_setup() {
	add_theme_support( 'infinite-scroll', array(
		'container' => 'content',
		'footer_widgets' => array( 'footer-1', 'footer-2', 'footer-3' ),
		'footer'    => 'page',
	) );
}
add_action( 'after_setup_theme', 'suits_jetpack_setup' );

/**
 * Add postMessage support for site title and description for the Customizer.
 *
 * @since Suits 1.0
 *
 * @param WP_Customize_Manager $wp_customize Customizer object.
 * @return void
 */
function suits_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
}
add_action( 'customize_register', 'suits_customize_register' );

/**
 * Binds JavaScript handlers to make Customizer preview reload changes
 * asynchronously.
 *
 * @since Suits 1.0
 */
function suits_customize_preview_js() {
	wp_enqueue_script( 'suits-customizer', get_template_directory_uri() . '/js/theme-customizer.js', array( 'customize-preview' ), '20131020', true );
}
add_action( 'customize_preview_init', 'suits_customize_preview_js' );

function mono_insert_into_db() {
 
    global $wpdb;
    // creates monoculture tables in database if not exists
  
    $sql = 
    "
        CREATE TABLE IF NOT EXISTS mono (
        id int NOT NULL AUTO_INCREMENT,
        species varchar(50) NOT NULL,
        best_temp decimal,
        doubletime int,
        growth_medium varchar(50),
        ph decimal,
        aerobic varchar(20),
        anaerobic varchar(20),
        gsheeturl varchar(2083),
        step1 varchar(1000) NULL,
        step2 varchar(1000) NULL,
        step3 varchar(1000) NULL,
        step4 varchar(1000) NULL,
        step5 varchar(1000) NULL,
        step6 varchar(1000) NULL,
        step7 varchar(1000) NULL,
        step8 varchar(1000) NULL,
        step9 varchar(1000) NULL,
        step10 varchar(1000) NULL,
        PRIMARY KEY(id),
        UNIQUE(id)
        )
    ";
    
    $wpdb->query($sql);
    
    if(((strpos($_SERVER['HTTP_USER_AGENT'], 'Safari')!==FALSE) && (strpos($_SERVER['HTTP_USER_AGENT'], 'Edge') === FALSE)
    && (strpos($_SERVER['HTTP_USER_AGENT'], 'Opera') === FALSE) && (strpos($_SERVER['HTTP_USER_AGENT'], 'OPR/') === FALSE)
    && (strpos($_SERVER['HTTP_USER_AGENT'], 'Chrome') === FALSE) && (strpos($_SERVER['HTTP_USER_AGENT'], 'Firefox') === FALSE)
    && (strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') === FALSE) && (strpos($_SERVER['HTTP_USER_AGENT'], 'Trident/7') === FALSE))===TRUE)
    {
        ?>
        <h1 style="text-align:center">ALICE is only compatible with browsers that are NOT Safari. Please use another web browser.</h1><br>
        <center><img align="middle" src='https://d13yacurqjgara.cloudfront.net/users/79821/screenshots/1150481/flat-browser-icons.jpg' /></center>
        <?php
    }
    else
    {
    global $wpdb;
    $mono_species=
            "
            SELECT species FROM mono
                   
            ";
    $co_species=
            "
            SELECT pop1, pop2 FROM co
                   
            ";
            
    $monosuggest=$wpdb->get_results($mono_species);            
    $cosuggest = $wpdb->get_results($co_species);
    
    echo "<datalist id=species>";
    
    foreach ($monosuggest as $row)
    {
    echo "<option value='$row->species'>";
    }
    
    foreach ($cosuggest as $row)
    {
    echo "<option value='$row->pop1'>";
    echo "<option value='$row->pop2'>";
    }
    
    echo "</datalist>";
    
    // starts output buffering
    ob_start();
    ?>
    <form action="#v_form" method="post" id="v_form">
    
        Species (required):<br><br>
        <input id="species" name="species" type="text" required pattern="[A-Z]{1}\.\s(.+)" title="eg. E. coli" list="species"/><br><br>
        Temperature in Celsius (required):<br><br> 
        <input id="best_temp" name="best_temp" type="number" required/><br><br>
        Doubling Time in minutes (required):<br> <br>
        <input id="doubletime" name="doubletime" type="number" min="0" required/><br><br>
        Growth Medium (required):<br> <br>
        <input id="growth_medium" name="growth_medium" type="text" required/><br><br>
        pH (required):<br><br>
        <input id="ph" name="ph" type="number" min="0" required/><br><br>
        <br>
        Aerobic (required):<br> <br>
        <br>
        <input name="aerobic" type="radio" value="Y" required/>Y<br><br>
        <input name="aerobic" type="radio" value="N" />N<br><br>
        <br>
        Anaerobic (required):<br> 
        <br>
        <input name="anaerobic" type="radio" value="Y" required/>Y <br><br>
        <input name="anaerobic" type="radio" value="Y (C+)" />Y (C+)<br><br>
        <input name="anaerobic" type="radio" value="Y (F.An)" />Y (F.An)<br><br>
        <input name="anaerobic" type="radio" value="N (C-)" />N (C-)<br><br>
        <input name="anaerobic" type="radio" value="N" />N<br><br>
        <br>
        <center> URL of <a href="https://sheets.google.com/create" target="_blank">Google Spreadsheet</a> containing OD data in <a href="https://www.mediafire.com/convkey/d739/2xt0yrl6ja933rm6g.jpg" target="_blank">correct configuration</a> (required):<br> 
        <br><input id="gsheeturl" name="gsheeturl" type="url" required pattern="https://docs\.google\.com/spreadsheets/d/(.+)|http://docs\.google\.com/spreadsheets/d/(.+)" title="eg. https://docs.google.com/spreadsheets/d/" size="500"/><br>
        <br>NOTE: This spreadsheet can still be edited by you after submission, which will result changes on the graph displayed when this entry is searched up.<br>
        <b><u>NEVER DELETE OR CHANGE THE LOCATION OF THIS SPREADSHEET AFTER THIS SUBMISSION IS SUCCESSFUL!!</u></b></center><br>        
        <br>
        Protocol Step 1:<br>        
        <input type="text" id='step1' name='step1' size="1000"/><br>
        <br>
        Protocol Step 2:<br>        
        <input type="text" id='step2' name='step2' size="1000"/><br>
        <br>
        Protocol Step 3:<br>        
        <input type="text" id='step3' name='step3' size="1000"/><br>
        <br>
        Protocol Step 4:<br>        
        <input type="text" id='step4' name='step4' size="1000"/><br>
        <br>
        Protocol Step 5:<br>        
        <input type="text" id='step5' name='step5' size="1000"/><br>
        <br>
        Protocol Step 6:<br>        
        <input type="text" id='step6' name='step6' size="1000"/><br>
        <br>
        Protocol Step 7:<br>        
        <input type="text" id='step7' name='step7' size="1000"/><br>
        <br>
        Protocol Step 8:<br>        
        <input type="text" id='step8' name='step8' size="1000"/><br>
        <br>
        Protocol Step 9:<br>        
        <input type="text" id='step9' name='step9' size="1000"/><br>
        <br>
        Protocol Step 10:<br>        
        <input type="text" id='step10' name='step10' size="1000"/><br>
        <br>        
        <center><input type="submit" name="submit_form" value="Submit monoculture growth experiment" size="150"/></center>
    </form>

    <?php

    $html = ob_get_clean();
    }
    // does the inserting, in case the form is filled and submitted
    if ( isset( $_POST["submit_form"] )){
        
        
        $species = strip_tags($_POST["species"], "");
        $best_temp=strip_tags($_POST["best_temp"],"");
        $doubletime=strip_tags($_POST["doubletime"],"");
        $growth_medium=strip_tags($_POST["growth_medium"],"");
        $ph=strip_tags($_POST["ph"],"");
        $gsheeturl=strip_tags($_POST["gsheeturl"],"");
        $aerobic=strip_tags($_POST["aerobic"],"");
        $anaerobic=strip_tags($_POST["anaerobic"],"");
        
        $step1 = strip_tags($_POST["step1"],"");
        $step2 = strip_tags($_POST["step2"],"");
        $step3 = strip_tags($_POST["step3"],"");
        $step4 = strip_tags($_POST["step4"],"");
        $step5 = strip_tags($_POST["step5"],"");
        $step6 = strip_tags($_POST["step6"],"");
        $step7 = strip_tags($_POST["step7"],"");
        $step8 = strip_tags($_POST["step8"],"");
        $step9 = strip_tags($_POST["step9"],"");
        $step10 = strip_tags($_POST["step10"],"");
      
        
        $wpdb->insert( 
            'mono', 
            array( 
                'species' => $species,
                'best_temp'=>$best_temp,
                'doubletime'=>$doubletime,
                'growth_medium'=>$growth_medium,
                'ph'=>$ph,
                'aerobic'=>$aerobic,
                'anaerobic'=>$anaerobic,
                'gsheeturl'=>$gsheeturl,
                'step1' => $step1,
                'step2'=>$step2,
                'step3'=>$step3,
                'step4'=>$step4,
                'step5'=>$step5,
                'step6'=>$step6,
                'step7'=>$step7,
                'step8'=>$step8,
                'step9'=>$step9,
                'step10'=>$step10
            )
        );
        
        $html = "<p>Your entry for <strong>$species</strong> was successfully recorded. Click to <a href='http://ecolibrium.eu.pn/submit-a-monoculture/'>submit another monoculture!</a></p>";
    }
    return $html;
}
// adds a shortcode you can use: [mono-db-insert]
add_shortcode('mono-db-insert', 'mono_insert_into_db');

function co_insert_into_db() {
 
    global $wpdb;
    // creates coculture tables in database if not exists
   
    $sql = 
    "
        CREATE TABLE IF NOT EXISTS co (
        id int NOT NULL AUTO_INCREMENT,
        pop1 varchar(50) NOT NULL,
        pop2 varchar(50) NOT NULL,
        best_temp decimal,
        ph decimal,
        growth_medium varchar(50),
        inoc_ratio varchar(20),
        inoc_time int,
        stable_time int,
        img_url varchar(2083),
        step1 varchar(1000) NULL,
        step2 varchar(1000) NULL,
        step3 varchar(1000) NULL,
        step4 varchar(1000) NULL,
        step5 varchar(1000) NULL,
        step6 varchar(1000) NULL,
        step7 varchar(1000) NULL,
        step8 varchar(1000) NULL,
        step9 varchar(1000) NULL,
        step10 varchar(1000) NULL,
        PRIMARY KEY(id),
        UNIQUE(id)
        )    
    ";
    
    $wpdb->query($sql);
    
    if(((strpos($_SERVER['HTTP_USER_AGENT'], 'Safari')!==FALSE) && (strpos($_SERVER['HTTP_USER_AGENT'], 'Edge') === FALSE)
    && (strpos($_SERVER['HTTP_USER_AGENT'], 'Opera') === FALSE) && (strpos($_SERVER['HTTP_USER_AGENT'], 'OPR/') === FALSE)
    && (strpos($_SERVER['HTTP_USER_AGENT'], 'Chrome') === FALSE) && (strpos($_SERVER['HTTP_USER_AGENT'], 'Firefox') === FALSE)
    && (strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') === FALSE) && (strpos($_SERVER['HTTP_USER_AGENT'], 'Trident/7') === FALSE))===TRUE)
    {
        ?>
        <h1 style="text-align:center">ALICE is only compatible with browsers that are NOT Safari. Please use another web browser.</h1><br>
        <center><img align="middle" src='https://d13yacurqjgara.cloudfront.net/users/79821/screenshots/1150481/flat-browser-icons.jpg' /></center>
        <?php
    }
    else
    {
    
    global $wpdb;
    $mono_species=
            "
            SELECT species FROM mono
                   
            ";
    $co_species=
            "
            SELECT pop1, pop2 FROM co
                   
            ";
            
    $monosuggest=$wpdb->get_results($mono_species);            
    $cosuggest = $wpdb->get_results($co_species);
    
    echo "<datalist id=species>";
    
    foreach ($monosuggest as $row)
    {
    echo "<option value='$row->species'>";
    }
    
    foreach ($cosuggest as $row)
    {
    echo "<option value='$row->pop1'>";
    echo "<option value='$row->pop2'>";
    }
    
    echo "</datalist>";
    
    // starts output buffering
    ob_start();
    ?>

    <form action="#v_form" method="post" id="v_form">
    
        Population 1 (required):<br><br>
        <input id="pop1" name="pop1" type="text" required pattern="[A-Z]{1}\.\s(.+)" title="eg. E. coli" list="species"/><br><br>
        Population 2 (required):<br><br> 
        <input id="pop2" name="pop2" type="text" required pattern="[A-Z]{1}\.\s(.+)" title="eg. E. coli" list="species"/><br><br>
        Temperature in Celsius (required):<br> <br>
        <input id="best_temp" name="best_temp" type="number" required/><br><br>
        pH (required):<br><br>
        <input id="ph" name="ph" type="number" min="0" required/><br><br>
        Growth Medium (required):<br> <br>
        <input id="growth_medium" name="growth_medium" type="text" required/><br><br>
        Hours of Growth after which Population 1 was Inoculated with Population 2 (required):<br><br>
        <input id="inoc_time" name="inoc_time" type="number" min="0" required/><br><br>
        Inoculation Ratio of Population 1 to Population 2 (required):<br> <br>
        <input id="pop1_ratio" name="pop1_ratio" type="number" min="1" required/> to <input id="pop2_ratio" name="pop2_ratio" type="number" min="1" required/><br><br>       
        Hours for which Stable Population Ratio was Maintained (required):<br><br>
        <input id="stable_time" name="stable_time" type="number" min="0" required/><br><br>
        <br><center><a href="https://www.mediafire.com/convkey/7a11/outb5a85uzcheus6g.jpg" target="_blank">Direct link URL</a> of an image file hosted online at <a href="https://www.mediafire.com/" target="_blank">MediaFire</a> to visualize growth data:<br><br>
        <input id="img_url" name="img_url" type="url" pattern="(http://|https://)www\.mediafire\.com/convkey/(.+)\.(jpg|png|gif|tif)" title="URL must be DIRECT LINK from MediaFire and end in .gif, .tif, .jpg, .png" size="500"/><br>
        <br>
        <b><u>NEVER DELETE OR CHANGE THE LOCATION OF THIS IMAGE FILE AFTER THIS SUBMISSION IS SUCCESSFUL!!</u></b></center><br>        
        <br>
        Protocol Step 1:<br>        
        <input type="text" id='step1' name='step1' size="1000"/><br>
        <br>
        Protocol Step 2:<br>        
        <input type="text" id='step2' name='step2' size="1000"/><br>
        <br>
        Protocol Step 3:<br>        
        <input type="text" id='step3' name='step3' size="1000"/><br>
        <br>
        Protocol Step 4:<br>        
        <input type="text" id='step4' name='step4' size="1000"/><br>
        <br>
        Protocol Step 5:<br>        
        <input type="text" id='step5' name='step5' size="1000"/><br>
        <br>
        Protocol Step 6:<br>        
        <input type="text" id='step6' name='step6' size="1000"/><br>
        <br>
        Protocol Step 7:<br>        
        <input type="text" id='step7' name='step7' size="1000"/><br>
        <br>
        Protocol Step 8:<br>        
        <input type="text" id='step8' name='step8' size="1000"/><br>
        <br>
        Protocol Step 9:<br>        
        <input type="text" id='step9' name='step9' size="1000"/><br>
        <br>
        Protocol Step 10:<br>        
        <input type="text" id='step10' name='step10' size="1000"/><br>
        <br>
        <center><input type="submit" name="submit_form" value="Submit co-culture growth experiment" size="250"/></center>
    </form>
 
    <?php
    
    $html = ob_get_clean();
    
    }
    // does the inserting, in case the form is filled and submitted
    if ( isset( $_POST["submit_form"] )){
      
        
        $pop1= strip_tags($_POST["pop1"], "");
        $pop2=strip_tags($_POST["pop2"],"");
        $best_temp=strip_tags($_POST["best_temp"],"");
        $growth_medium=strip_tags($_POST["growth_medium"],"");
        $ph=strip_tags($_POST["ph"],"");
        $inoc_ratio=strip_tags($_POST["pop1_ratio"],"").':'.strip_tags($_POST['pop2_ratio'],"");
        $inoc_time=strip_tags($_POST["inoc_time"],"");
        $stable_time=strip_tags($_POST["stable_time"],"");
        $img_url=strip_tags($_POST["img_url"],"");
      
        $step1 = strip_tags($_POST["step1"],"");
        $step2 = strip_tags($_POST["step2"],"");
        $step3 = strip_tags($_POST["step3"],"");
        $step4 = strip_tags($_POST["step4"],"");
        $step5 = strip_tags($_POST["step5"],"");
        $step6 = strip_tags($_POST["step6"],"");
        $step7 = strip_tags($_POST["step7"],"");
        $step8 = strip_tags($_POST["step8"],"");
        $step9 = strip_tags($_POST["step9"],"");
        $step10 = strip_tags($_POST["step10"],"");
        
        $wpdb->insert( 
            'co', 
            array( 
                'pop1' => $pop1,
                'pop2'=>$pop2,
                'best_temp'=>$best_temp,
                'growth_medium'=>$growth_medium,
                'ph'=>$ph,
                'inoc_ratio'=>$inoc_ratio,
                'inoc_time'=>$inoc_time,
                'stable_time'=>$stable_time,
                'img_url'=>$img_url,
                'step1' => $step1,
                'step2'=>$step2,
                'step3'=>$step3,
                'step4'=>$step4,
                'step5'=>$step5,
                'step6'=>$step6,
                'step7'=>$step7,
                'step8'=>$step8,
                'step9'=>$step9,
                'step10'=>$step10
            )
        );
        
        $html = "<p>Your entry for <strong>$pop1</strong> and <strong>$pop2</strong> was successfully recorded. Click to <a href='http://ecolibrium.eu.pn/submit/'>submit another co-culture!</a></p>";
    }
    return $html;
     
}
// adds a shortcode you can use: [co-db-insert]
add_shortcode('co-db-insert', 'co_insert_into_db');

add_filter('protected_title_format', 'blank');
function blank($title) {
       return '%s';
}

function my_password_form() {
    global $post;
    $label = 'pwbox-'.( empty( $post->ID ) ? rand() : $post->ID );
    $o = '<form action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post">
    ' . __( "<a href='http://ecolibrium.eu.pn/sign-up-for-submission-privileges/'>Request permission now</a> to submit entries to A.L.I.C.E or enter your password below:") . '
    <label for="' . $label . '">' . __( "<br>Password:" ) . ' </label><input name="post_password" id="' . $label . '" type="password" size="20" maxlength="20" /><input type="submit" name="Submit" value="' . esc_attr__( "Submit" ) . '" />
    </form>
    ';
    return $o;
}
add_filter( 'the_password_form', 'my_password_form' );

function search_db()
{

    if(((strpos($_SERVER['HTTP_USER_AGENT'], 'Safari')!==FALSE) && (strpos($_SERVER['HTTP_USER_AGENT'], 'Edge') === FALSE)
    && (strpos($_SERVER['HTTP_USER_AGENT'], 'Opera') === FALSE) && (strpos($_SERVER['HTTP_USER_AGENT'], 'OPR/') === FALSE)
    && (strpos($_SERVER['HTTP_USER_AGENT'], 'Chrome') === FALSE) && (strpos($_SERVER['HTTP_USER_AGENT'], 'Firefox') === FALSE)
    && (strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') === FALSE) && (strpos($_SERVER['HTTP_USER_AGENT'], 'Trident/7') === FALSE))===TRUE)
    {
        ?>
        <h1 style="text-align:center">ALICE is only compatible with browsers that are NOT Safari. Please use another web browser.</h1><br>
        <center><img align="middle" src='https://d13yacurqjgara.cloudfront.net/users/79821/screenshots/1150481/flat-browser-icons.jpg' /></center>
        <?php
    }
    else
    {
    global $wpdb;
    $mono_species=
            "
            SELECT species FROM mono
                   
            ";
    $co_species=
            "
            SELECT pop1, pop2 FROM co
                   
            ";
            
    $monosuggest=$wpdb->get_results($mono_species);            
    $cosuggest = $wpdb->get_results($co_species);
    
    echo "<datalist id=species>";
    
    foreach ($monosuggest as $row)
    {
    echo "<option value='$row->species'>";
    }
    
    foreach ($cosuggest as $row)
    {
    echo "<option value='$row->pop1'>";
    echo "<option value='$row->pop2'>";
    }
    
    echo "</datalist>";
    
    
    ob_start();
    ?>

    <h1 style="text-align:center">Which 2 species are you looking to co-culture together?</h1><br><br>
   
    <center><form action="#v_form#top" method="post" id="v_form">
    
        Population 1 (required):<br><br> 
        <input id="pop1" name="pop1" type="text" required pattern="[A-Z]{1}\.\s(.+)" title="eg. E. coli" list="species"/><br><br>
        Population 2 (required):<br> <br>
        <input id="pop2" name="pop2" type="text" required pattern="[A-Z]{1}\.\s(.+)" title="eg. E. coli" list="species"/><br><br>
        <br>
        <input type="submit" name="submit_form" value="Search" />
    </form></center>
    <?php
    $html = ob_get_clean();

    
    //Search the database:
    global $wpdb;
    
    if ( isset( $_POST["submit_form"] )) 
    
    {
            $pop1= strip_tags($_POST["pop1"], "");
            $pop2=strip_tags($_POST["pop2"],"");
            
            //search co-cultures entered into the database    
            $sql = 
            "
            SELECT * FROM co
            WHERE 
            (co.pop1 LIKE '%$pop1%' OR co.pop1 LIKE '%$pop2%') 
            AND 
            (co.pop2 LIKE '%$pop1%' OR co.pop2 LIKE '%$pop2%')  
                    
            ";
            
            //identify monocultures of the 2 inputted populations
            
            $sql1=
            "
            
            SELECT * 
            FROM mono 
            WHERE (mono.species LIKE '%$pop1%')             
            ORDER BY doubletime ASC, best_temp ASC, ph ASC
                      
            
            ";
            
            $sql2=
            "
            SELECT * 
            FROM mono 
            WHERE (mono.species LIKE '%$pop2%')
            ORDER BY doubletime ASC, best_temp ASC, ph ASC
                      
            
            ";
            
            $mono_result2=$wpdb->get_results($sql2);
            $mono_result1=$wpdb->get_results($sql1);            
            $co_result = $wpdb->get_results($sql);
            
            /* Print the contents of $co_result looping through each row returned in the result */
            
            echo "<center><h1 style='color:blue;'>Your search for <strong>$pop1</strong> and <strong>$pop2</strong> was executed.</h1></center>";
            
            if (!empty($co_result))
            {
            
                 echo "<br><br><h2 style='color:blue; text-align:center;'><u>Co-cultures of $pop1 or $pop2:</u></h2>";
            }
            
            if (empty($co_result))
            {
            
                 echo "<br><br><b style='color:red; text-align:center;'>No co-cultures of $pop1 or $pop2 found.</b><br>";
            }

            foreach($co_result as $row)
            {
                                  
                 
                 
                 //growth conditions in its own table
                 echo "<br><br><table><tr><th style='text-align:center'>Species 1</th><th style='text-align:center'>Species 2</th><th style='text-align:center'>Medium</th><th style='text-align:right'>pH</th><th style='text-align:center'>Temperature<br>(Celsius)</th><th style='text-align:center'>Inoculation Ratio<br>(Species 1 : Species 2)</th><th style='text-align:center'>Inoculation<br>Timepoint (h)</th><th style='text-align:center'>Stable<br>Population Time (h)</th></tr>";
                 echo "<tr><td style='text-align:center'>$row->pop1</td><td style='text-align:center'>$row->pop2</td><td style='text-align:center'>$row->growth_medium</td><td style='text-align:right'>$row->ph</td><td style='text-align:center'>$row->best_temp</td><td style='text-align:center'>$row->inoc_ratio</td><td style='text-align:center'>$row->inoc_time</td><td style='text-align:center'>$row->stable_time</td></tr>";
                 echo "</table>";
                 
                 //image of any experimental data submitted with entry
                 if (!empty($row->img_url))
                 {
                         echo "<center><img src=$row->img_url></center><br>";
                 }
                 
                 //all protocol in a list
                 echo "<center><h3><u><b>PROTOCOL</b></u></h3></center>";

                 if (!empty($row->step1))
                 {
                         echo "Step 1: $row->step1<br>";
                 }
                 if (!empty($row->step2))
                 {
                         echo "<br>Step 2: $row->step2<br>";
                 }
                 if (!empty($row->step3))
                 {
                         echo "<br>Step 3: $row->step3<br>";
                 }
                 if (!empty($row->step4))
                 {
                         echo "<br>Step 4: $row->step4<br>";
                 }
                 if (!empty($row->step5))
                 {
                         echo "<br>Step 5: $row->step5<br>";
                 }
                 if (!empty($row->step6))
                 {
                         echo "<br>Step 6: $row->step6<br>";
                 }
                 if (!empty($row->step7))
                 {
                         echo "<br>Step 7: $row->step7<br>";
                 }
                 if (!empty($row->step8))
                 {
                         echo "<br>Step 8: $row->step8<br>";
                 }
                 if (!empty($row->step9))
                 {
                         echo "<br>Step 9: $row->step9<br>";
                 }
                 if (!empty($row->step10))
                 {
                         echo "<br>Step 10: $row->step10<br>";
                 }
                 
                 
            }
            
            if (empty($mono_result1))
            {
                    echo "<br><b style='color:red;'>No monocultures of $pop1 found.</b><br>";
            }
            
            if (empty($mono_result2))
            {
                    echo "<br><b style='color:red;'>No monocultures of $pop2 found.</b><br>";
            }
            
            echo "<table>";
            echo "<tr>";
                 
                    
                    
                    if (!empty($mono_result1) || !empty($mono_result2))
                    {
                             if (!empty($mono_result1))
                             {
                                 echo "<br><br><th style='color:blue; text-align:left;'>Monocultures of $pop1:</th>";
                             }
                             if (!empty($mono_result2))
                             {
                                 echo "<br><br><th style='color:blue; text-align:left;'>Monocultures of $pop2:</th>";
                             }
                             echo "</tr>";
                             echo "<tr>";
                    }
                    
                    if (!empty($mono_result1))
                    {   
                    
                            echo "<td valign='top' style='width:470px'>";
                            
                            //create a table for each monoculture entry of population 1:
                            foreach($mono_result1 as $row)
                            {
                
                                 
                                 
                                 //growth conditions 
                                 echo "<br><table><tr><th style='text-align:center'>Species</th><th style='text-align:center'>Doubling<br>Time (min)</th><th style='text-align:center'>Temperature<br>(Celsius)</th><th style='text-align:center'>pH</th><th style='text-align:center'>Medium</th><th style='text-align:center'>Aerobic</th><th style='text-align:center'>Anaerobic</th></tr>";
                                 echo "<tr><td style='text-align:center'>$row->species</td><td style='text-align:center'>$row->doubletime</td><td style='text-align:center'>$row->best_temp</td><td style='text-align:center'>$row->ph</td><td style='text-align:center'>$row->growth_medium</td><td style='text-align:center'>$row->aerobic</td><td style='text-align:center'>$row->anaerobic</td></tr>";
                                 
                                 //graph of O.D data submitted with entry
                                 
                                 echo "<tr><td colspan='7'>";
                                 echo do_shortcode("[gdoc key=$row->gsheeturl title='Optical Density over Time (hours)' chart='Line' ]");
                                 echo "</td></tr>";
                                
                                 //all protocol in a list
                                 
                                 echo "<tr><th colspan='7' style='text-align:center'><b>PROTOCOL</b></th></tr>";
                                 if (!empty($row->step1))
                                 {
                                         echo "<tr><td colspan='7' >Step 1: $row->step1</td></tr>";
                                 }
                                 if (!empty($row->step2))
                                 {
                                         echo "<tr><td colspan='7' >Step 2: $row->step2</td></tr>";
                                 }
                                 if (!empty($row->step3))
                                 {
                                         echo "<tr><td colspan='7' >Step 3: $row->step3</td></tr>";
                                 }
                                 if (!empty($row->step4))
                                 {
                                         echo "<tr><td colspan='7' >Step 4: $row->step4</td></tr>";
                                 }
                                 if (!empty($row->step5))
                                 {
                                         echo "<tr><td colspan='7' >Step 5: $row->step5</td></tr>";
                                 }
                                 if (!empty($row->step6))
                                 {
                                         echo "<tr><td colspan='7' >Step 6: $row->step6</td></tr>";
                                 }
                                 if (!empty($row->step7))
                                 {
                                         echo "<tr><td colspan='7' >Step 7: $row->step7</td></tr>";
                                 }
                                 if (!empty($row->step8))
                                 {
                                         echo "<tr><td colspan='7' >Step 8: $row->step8</td></tr>";
                                 }
                                 if (!empty($row->step9))
                                 {
                                         echo "<tr><td colspan='7' >Step 9: $row->step9</td></tr>";
                                 }
                                 if (!empty($row->step10))
                                 {
                                         echo "<tr><td colspan='7' >Step 10: $row->step10</td></tr>";
                                 }
                                                      
                                 
                                 echo "</table>";
                                 
                            }
                            echo "</td>";
                    }
                    
                    if (!empty($mono_result2))
                    {
                            echo "<td valign='top' style='470px'>";
                            //create tables for each monoculture entry of population 2:
                            foreach($mono_result2 as $row)
                            {
                                    
                                 
                                 //growth conditions 
                                 echo "<br><table border='0'><tr><th style='text-align:center'>Species</th><th style='text-align:center'>Doubling<br>Time (min)</th><th style='text-align:center'>Temperature<br>(Celsius)</th><th style='text-align:center'>pH</th><th style='text-align:center'>Medium</th><th style='text-align:center'>Aerobic</th><th style='text-align:center'>Anaerobic</th></tr>";
                                 echo "<tr><td style='text-align:center'>$row->species</td><td style='text-align:center'>$row->doubletime</td><td style='text-align:center'>$row->best_temp</td><td style='text-align:center'>$row->ph</td><td style='text-align:center'>$row->growth_medium</td><td style='text-align:center'>$row->aerobic</td><td style='text-align:center'>$row->anaerobic</td></tr>";
                                 
                                
                                //graph of O.D data submitted with entry
                                 echo "<tr><td colspan='7'>";
                                 echo do_shortcode("[gdoc key=$row->gsheeturl title='Optical Density over Time (hours)' chart='Line' ]");
                                 echo "</td></tr>";
                                
                                 //all protocol in a list
                                 echo "<tr><th colspan='7' style='text-align:center'><b>PROTOCOL</b></th></tr>";
                                 if (!empty($row->step1))
                                 {
                                         echo "<tr><td colspan='7' >Step 1: $row->step1</td></tr>";
                                 }
                                 if (!empty($row->step2))
                                 {
                                         echo "<tr><td colspan='7' >Step 2: $row->step2</td></tr>";
                                 }
                                 if (!empty($row->step3))
                                 {
                                         echo "<tr><td colspan='7' >Step 3: $row->step3</td></tr>";
                                 }
                                 if (!empty($row->step4))
                                 {
                                         echo "<tr><td colspan='7' >Step 4: $row->step4</td></tr>";
                                 }
                                 if (!empty($row->step5))
                                 {
                                         echo "<tr><td colspan='7' >Step 5: $row->step5</td></tr>";
                                 }
                                 if (!empty($row->step6))
                                 {
                                         echo "<tr><td colspan='7' >Step 6: $row->step6</td></tr>";
                                 }
                                 if (!empty($row->step7))
                                 {
                                         echo "<tr><td colspan='7' >Step 7: $row->step7</td></tr>";
                                 }
                                 if (!empty($row->step8))
                                 {
                                         echo "<tr><td colspan='7' >Step 8: $row->step8</td></tr>";
                                 }
                                 if (!empty($row->step9))
                                 {
                                         echo "<tr><td colspan='7' >Step 9: $row->step9</td></tr>";
                                 }
                                 if (!empty($row->step10))
                                 {
                                         echo "<tr><td colspan='7' >Step 10: $row->step10</td></tr>";
                                 }
                                 
                                 echo "</table>";
                                 
                                 
                            }
                    
                            echo "</td>";
                    }
                    
            echo "</tr>";
            echo "</table>";
            
                       
            echo "<br><br><h1 style=' text-align:left;'><u>Try another search:</u></h1>";
    }
    
    return $html;
    }
}
// adds a shortcode you can use: [search-db]
add_shortcode('search-db', 'search_db');

function redirect($url) {
    ob_start();
    header('Location: '.$url);
    ob_end_flush();
    die();
}

function url_get_contents ($Url) {
    if (!function_exists('curl_init')){ 
        die('CURL is not installed!');
    }
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $Url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    $output = curl_exec($ch);
    curl_close($ch);
    return $output;
}

function captcha_form()
{
        ?>
        
        <script src="https://www.google.com/recaptcha/api.js" async defer></script>
        <center>
        <form method="POST">
                <div class="g-recaptcha" data-sitekey="6LeaMygTAAAAAOq9OntnPC1VEe0WzmgYobV5v5Ag"></div>
                <input name="submit" type="submit" value="Proceed">
        </form>
        </center>

        
        <?php
        
        $captcha;
        
        if((isset($_POST['submit']))&&( $_SERVER["REQUEST_METHOD"] === "POST"))
        {        
                $captcha=$_POST['g-recaptcha-response'];                        
                $secretKey = "6LeaMygTAAAAAAZ91HZghzAYPxGpEIXIivpMyzoc";
 
                $response=url_get_contents("https://www.google.com/recaptcha/api/siteverify?secret=".$secretKey."&response=".$captcha);
                $response = json_decode($response,true);
                
                if($response["success"]===true) 
                {
                        redirect("http://ecolibrium.eu.pn/email-instructions-to-obtain-permission-to-submit/");
                } 
                
        }

}
// adds a shortcode you can use: [captcha-form]
add_shortcode('captcha-form', 'captcha_form');			
                        